package com.game.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.game.common.core.domain.R;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.game.common.annotation.Log;
import com.game.common.core.controller.BaseController;
import com.game.common.core.domain.AjaxResult;
import com.game.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.game.business.domain.AppUserAgent;
import com.game.business.service.IAppUserAgentService;
import com.game.common.utils.poi.ExcelUtil;
import com.game.common.core.page.TableDataInfo;

/**
 * 用户代理表Controller
 * 
 * @author game
 * @date 2024-06-25
 */
@RestController
@RequestMapping("/business/agent")
@Api(value = "AppUserAgentController", description = "用户代理表接口", tags = {"用户代理表"})
public class AppUserAgentController extends BaseController
{
    @Autowired
    private IAppUserAgentService appUserAgentService;

    /**
     * 查询用户代理表列表
     */
    @PreAuthorize("@ss.hasPermi('business:agent:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询用户代理表列表", notes = "获取用户代理表列表")
    public TableDataInfo<AppUserAgent> list(AppUserAgent appUserAgent)
    {
        startPage();
        List<AppUserAgent> list = appUserAgentService.selectAppUserAgentList(appUserAgent);
        return getDataTable(list);
    }

    /**
     * 导出用户代理表列表
     */
    @PreAuthorize("@ss.hasPermi('business:agent:export')")
    @Log(title = "用户代理表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出用户代理表列表", notes = "导出用户代理表列表")
    public void export(HttpServletResponse response, AppUserAgent appUserAgent)
    {
        List<AppUserAgent> list = appUserAgentService.selectAppUserAgentList(appUserAgent);
        ExcelUtil<AppUserAgent> util = new ExcelUtil<AppUserAgent>(AppUserAgent.class);
        util.exportExcel(response, list, "用户代理表数据");
    }

    /**
     * 获取用户代理表详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:agent:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取用户代理表详细信息", notes = "获取用户代理表详细信息")
    public R<AppUserAgent> getInfo(@PathVariable("id") Long id)
    {
        return R.ok(appUserAgentService.selectAppUserAgentById(id));
    }

    /**
     * 新增用户代理表
     */
    @PreAuthorize("@ss.hasPermi('business:agent:add')")
    @Log(title = "用户代理表", businessType = BusinessType.INSERT)
    @ApiOperation(value = "新增用户代理表", notes = "新增用户代理表")
    @PostMapping
    public R add(@RequestBody AppUserAgent appUserAgent)
    {
        return R.ok(appUserAgentService.insertAppUserAgent(appUserAgent));
    }

    /**
     * 修改用户代理表
     */
    @PreAuthorize("@ss.hasPermi('business:agent:edit')")
    @Log(title = "用户代理表", businessType = BusinessType.UPDATE)
    @ApiOperation(value = "修改用户代理表", notes = "修改用户代理表")
    @PutMapping
    public R edit(@RequestBody AppUserAgent appUserAgent)
    {
        return R.ok(appUserAgentService.updateAppUserAgent(appUserAgent));
    }

    /**
     * 删除用户代理表
     */
    @PreAuthorize("@ss.hasPermi('business:agent:remove')")
    @Log(title = "用户代理表", businessType = BusinessType.DELETE)
    @ApiOperation(value = "删除用户代理表", notes = "删除用户代理表")
	@DeleteMapping("/{ids}")
    public R remove(@PathVariable Long[] ids)
    {
        return R.ok(appUserAgentService.deleteAppUserAgentByIds(ids));
    }
}
